@@ -1,5 +1,5 @@
 /*
-	libmpg123: MPEG Audio Decoder library (version 1.28.0)
+	libmpg123: MPEG Audio Decoder library (version 1.30.1)
 
 	copyright 1995-2015 by the mpg123 project
 	free software under the terms of the LGPL 2.1
@@ -17,7 +17,9 @@
  * This should be incremented at least each time a new symbol is added
  * to the header.
  */
-#define MPG123_API_VERSION 46
+#ifndef MPG123_API_VERSION
+#define MPG123_API_VERSION 47
+#endif
 
 #ifndef MPG123_EXPORT
 /** Defines needed for MS Visual Studio(tm) DLL builds.
@@ -41,13 +43,6 @@
 #endif
 #endif
 
-/* This is for Visual Studio, so this header works as distributed in the binary downloads */
-#if defined(_MSC_VER) && !defined(MPG123_DEF_SSIZE_T)
-#define MPG123_DEF_SSIZE_T
-#include <stddef.h>
-typedef ptrdiff_t ssize_t;
-#endif
-
 /** Earlier versions of libmpg123 put enums into public API calls,
  * thich is not exactly safe. There are ABI rules, but you can use
  * compiler switches to change the sizes of enums. It is safer not
@@ -76,9 +71,22 @@ typedef ptrdiff_t ssize_t;
 
 #endif
 
+/* You can use this file directly, avoiding the autoconf replacements.
+   Might have to set MPG123_NO_LARGENAME, too, in case you have
+   _FILE_OFFSET_BITS defined where it does not make sense. */
+#ifndef MPG123_NO_CONFIGURE
+
 #include <stdlib.h>
 #include <sys/types.h>
 
+/* A little hack to help MSVC not having ssize_t. */
+#ifdef _MSC_VER
+#include <stddef.h>
+typedef ptrdiff_t mpg123_ssize_t;
+#else
+typedef ssize_t mpg123_ssize_t;
+#endif
+
 /* You can always enforce largefile hackery by setting MPG123_LARGESUFFIX. */
 /* Otherwise, this header disables it if the build system decided so. */
 #if !defined(MPG123_LARGESUFFIX) && 0
@@ -87,6 +95,8 @@ typedef ptrdiff_t ssize_t;
 #endif
 #endif
 
+#endif /* MPG123_NO_CONFIGURE */
+
 /* Simplified large file handling.
 	I used to have a check here that prevents building for a library with conflicting large file setup
 	(application that uses 32 bit offsets with library that uses 64 bits).
@@ -388,7 +398,7 @@ enum mpg123_feature_set
 	,MPG123_FEATURE_EQUALIZER            /**< tunable equalizer */
 	,MPG123_FEATURE_MOREINFO             /**< more info extraction (for frame analyzer) */
 	,MPG123_FEATURE_OUTPUT_FLOAT32      /**< 32 bit float output */
-	,MPG123_FEATURE_OUTPUT_FLOAT64      /**< 64 bit float output (usually never) */
+	,MPG123_FEATURE_OUTPUT_FLOAT64      /**< 64 bit float output (as of now: never!) */
 };
 
 #ifdef MPG123_ENUM_API
@@ -1083,6 +1093,28 @@ MPG123_EXPORT int mpg123_eq( mpg123_handle *mh
 MPG123_EXPORT int mpg123_eq2( mpg123_handle *mh
 ,	int channel, int band, double val );
 
+/** Set a range of equalizer bands
+ *  \param channel Can be #MPG123_LEFT, #MPG123_RIGHT or
+ *    #MPG123_LEFT|#MPG123_RIGHT for both.
+ *  \param a The first equalizer band to set (from 0 to 31)
+ *  \param b The last equalizer band to set (from 0 to 31)
+ *  \param factor The (linear) adjustment factor, 1 being neutral.
+ *  \return MPG123_OK on success
+ */
+MPG123_EXPORT int mpg123_eq_bands( mpg123_handle *mh
+,	int channel, int a, int b, double factor );
+
+/** Change a range of equalizer bands
+ *  \param channel Can be #MPG123_LEFT, #MPG123_RIGHT or
+ *    #MPG123_LEFT|#MPG123_RIGHT for both.
+ *  \param a The first equalizer band to change (from 0 to 31)
+ *  \param b The last equalizer band to change (from 0 to 31)
+ *  \param db The adjustment in dB (limited to +/- 60 dB).
+ *  \return MPG123_OK on success
+ */
+MPG123_EXPORT int mpg123_eq_change( mpg123_handle *mh
+,	int channel, int a, int b, double db );
+
 #ifdef MPG123_ENUM_API
 /** Get the 32 Band Audio Equalizer settings.
  *
@@ -1131,6 +1163,13 @@ MPG123_EXPORT int mpg123_volume(mpg123_handle *mh, double vol);
  */
 MPG123_EXPORT int mpg123_volume_change(mpg123_handle *mh, double change);
 
+/** Adjust output volume including the RVA setting by chosen amount
+ *  \param mh handle
+ *  \param change volume adjustment in decibels (limited to +/- 60 dB)
+ *  \return MPG123_OK on success
+ */
+MPG123_EXPORT int mpg123_volume_change_db(mpg123_handle *mh, double db);
+
 /** Return current volume setting, the actual value due to RVA, and the RVA 
  *  adjustment itself. It's all as double float value to abstract the sample 
  *  format. The volume values are linear factors / amplitudes (not percent) 
@@ -1731,7 +1770,7 @@ MPG123_EXPORT int mpg123_id3( mpg123_handle *mh
 ,	mpg123_id3v1 **v1, mpg123_id3v2 **v2 );
 
 /** Return pointers to and size of stored raw ID3 data if storage has
- *  been configured with MPG123_RAW_ID3 and stream parsing passed the
+ *  been configured with MPG123_STORE_RAW_ID3 and stream parsing passed the
  *  metadata already. Null value with zero size is a possibility!
  *  The storage can change at any next API call.
  *
@@ -1959,7 +1998,7 @@ MPG123_EXPORT size_t mpg123_outblock(mpg123_handle *mh);
  * \return MPG123_OK on success
  */
 MPG123_EXPORT int mpg123_replace_reader( mpg123_handle *mh
-,	ssize_t (*r_read) (int, void *, size_t)
+,	mpg123_ssize_t (*r_read) (int, void *, size_t)
 ,	off_t (*r_lseek)(int, off_t, int)
 );
 
@@ -1978,7 +2017,7 @@ MPG123_EXPORT int mpg123_replace_reader( mpg123_handle *mh
  * \return MPG123_OK on success
  */
 MPG123_EXPORT int mpg123_replace_reader_handle( mpg123_handle *mh
-,	ssize_t (*r_read) (void *, void *, size_t)
+,	mpg123_ssize_t (*r_read) (void *, void *, size_t)
 ,	off_t (*r_lseek)(void *, off_t, int)
 ,	void (*cleanup)(void*) );
 
